@@ -14,6 +14,7 @@ declare(strict_types=1);
 
 namespace KevinGH\Box\Configuration;
 
+use Throwable;
 use function array_diff;
 use function array_filter;
 use function array_flip;
@@ -24,7 +25,6 @@ use function array_merge;
 use function array_unique;
 use function array_values;
 use function array_walk;
-use Assert\Assertion;
 use Closure;
 use function constant;
 use function current;
@@ -32,16 +32,15 @@ use DateTimeImmutable;
 use DateTimeZone;
 use function defined;
 use function dirname;
+use function str_starts_with;
 use const E_USER_DEPRECATED;
 use function explode;
 use function file_exists;
 use function getcwd;
 use Herrera\Box\Compactor\Json as LegacyJson;
 use Herrera\Box\Compactor\Php as LegacyPhp;
-use Humbug\PhpScoper\Configuration as PhpScoperConfiguration;
-use Humbug\PhpScoper\Console\ApplicationFactory;
-use Humbug\PhpScoper\Scoper;
-use Humbug\PhpScoper\Scoper\FileWhitelistScoper;
+use Humbug\PhpScoper\Configuration\Configuration as PhpScoperConfiguration;
+use Humbug\PhpScoper\Container;
 use function implode;
 use function in_array;
 use function intval;
@@ -56,10 +55,10 @@ use function is_string;
 use function iter\map;
 use function iter\toArray;
 use function iter\values;
-use KevinGH\Box\Annotation\AnnotationDumper;
+use KevinGH\Box\Annotation\CompactedFormatter;
 use KevinGH\Box\Annotation\DocblockAnnotationParser;
-use KevinGH\Box\Annotation\DocblockParser;
 use KevinGH\Box\Compactor\Compactor;
+use KevinGH\Box\Compactor\Compactors;
 use KevinGH\Box\Compactor\Json as JsonCompactor;
 use KevinGH\Box\Compactor\Php as PhpCompactor;
 use KevinGH\Box\Compactor\PhpScoper as PhpScoperCompactor;
@@ -81,6 +80,7 @@ use KevinGH\Box\PhpScoper\SimpleScoper;
 use function KevinGH\Box\unique_id;
 use function krsort;
 use Phar;
+use phpDocumentor\Reflection\DocBlockFactory;
 use function preg_match;
 use function preg_replace;
 use function property_exists;
@@ -101,6 +101,7 @@ use Symfony\Component\VarDumper\Cloner\VarCloner;
 use Symfony\Component\VarDumper\Dumper\CliDumper;
 use function trigger_error;
 use function trim;
+use Webmozart\Assert\Assert;
 
 /**
  * @private
@@ -317,7 +318,7 @@ BANNER;
         );
 
         /**
-         * @var string[]
+         * @var string[] $excludedPaths
          * @var Closure  $blacklistFilter
          */
         [$excludedPaths, $blacklistFilter] = self::retrieveBlacklistFilter(
@@ -388,7 +389,7 @@ BANNER;
         $privateKeyPath = self::retrievePrivateKeyPath($raw, $basePath, $signingAlgorithm, $logger);
         $privateKeyPassphrase = self::retrievePrivateKeyPassphrase($raw, $signingAlgorithm, $logger);
 
-        $replacements = self::retrieveReplacements($raw, $file, $logger);
+        $replacements = self::retrieveReplacements($raw, $file, $basePath, $logger);
 
         return new self(
             $file,
@@ -442,7 +443,6 @@ BANNER;
      * @param bool          $dumpAutoload         Whether or not the Composer autoloader should be dumped
      * @param bool          $excludeComposerFiles Whether or not the Composer files composer.json, composer.lock and
      *                                            installed.json should be removed from the PHAR
-     * @param Compactor[]   $compactors           List of file contents compactors
      * @param null|int      $compressionAlgorithm Compression algorithm constant value. See the \Phar class constants
      * @param null|int      $fileMode             File mode in octal form
      * @param string        $mainScriptPath       The main script file path
@@ -475,7 +475,7 @@ BANNER;
         bool $dumpAutoload,
         bool $excludeComposerFiles,
         bool $excludeDevPackages,
-        array $compactors,
+        Compactors $compactors,
         ?int $compressionAlgorithm,
         ?int $fileMode,
         ?string $mainScriptPath,
@@ -499,19 +499,19 @@ BANNER;
         array $warnings,
         array $recommendations
     ) {
-        Assertion::nullOrInArray(
+        Assert::nullOrInArray(
             $compressionAlgorithm,
             get_phar_compression_algorithms(),
             sprintf(
-                'Invalid compression algorithm "%%s", use one of "%s" instead.',
+                'Invalid compression algorithm %%s, use one of "%s" instead.',
                 implode('", "', array_keys(get_phar_compression_algorithms()))
             )
         );
 
         if (null === $mainScriptPath) {
-            Assertion::null($mainScriptContents);
+            Assert::null($mainScriptContents);
         } else {
-            Assertion::notNull($mainScriptContents);
+            Assert::notNull($mainScriptContents);
         }
 
         $this->file = $file;
@@ -602,7 +602,7 @@ BANNER;
 
         $exportedConfig->compressionAlgorithm = array_flip(get_phar_compression_algorithms())[$exportedConfig->compressionAlgorithm ?? Phar::NONE];
         $exportedConfig->signingAlgorithm = array_flip(get_phar_signing_algorithms())[$exportedConfig->signingAlgorithm];
-        $exportedConfig->compactors = array_map('get_class', $exportedConfig->compactors);
+        $exportedConfig->compactors = array_map('get_class', $exportedConfig->compactors->toArray());
         $exportedConfig->fileMode = '0'.decoct($exportedConfig->fileMode);
 
         $cloner = new VarCloner();
@@ -618,7 +618,7 @@ BANNER;
             SymfonySplFileInfo::class => $splInfoCaster,
         ]);
 
-        return (new CliDumper())->dump(
+        return (string) (new CliDumper())->dump(
             $cloner->cloneVar($exportedConfig),
             true
         );
@@ -695,10 +695,7 @@ BANNER;
         return $this->excludeDevFiles;
     }
 
-    /**
-     * @return Compactor[] the list of compactors
-     */
-    public function getCompactors(): array
+    public function getCompactors(): Compactors
     {
         return $this->compactors;
     }
@@ -720,7 +717,7 @@ BANNER;
 
     public function getMainScriptPath(): string
     {
-        Assertion::notNull(
+        Assert::notNull(
             $this->mainScriptPath,
             'Cannot retrieve the main script path: no main script configured.'
         );
@@ -730,7 +727,7 @@ BANNER;
 
     public function getMainScriptContents(): string
     {
-        Assertion::notNull(
+        Assert::notNull(
             $this->mainScriptPath,
             'Cannot retrieve the main script contents: no main script configured.'
         );
@@ -858,7 +855,7 @@ BANNER;
 
         $alias = trim($raw->{self::ALIAS_KEY});
 
-        Assertion::notEmpty($alias, 'A PHAR alias cannot be empty when provided.');
+        Assert::notEmpty($alias, 'A PHAR alias cannot be empty when provided.');
 
         if ($userStubUsed) {
             $logger->addWarning(
@@ -884,9 +881,9 @@ BANNER;
 
         $basePath = trim($raw->{self::BASE_PATH_KEY});
 
-        Assertion::directory(
+        Assert::directory(
             $basePath,
-            'The base path "%s" is not a directory or does not exist.'
+            'The base path %s is not a directory or does not exist.'
         );
 
         $basePath = realpath($basePath);
@@ -1123,12 +1120,12 @@ BANNER;
 
         $files = array_merge((array) $raw->{$key}, $files);
 
-        Assertion::allString($files);
+        Assert::allString($files);
 
         $normalizePath = static function (string $file) use ($basePath, $key, $excludedFiles): ?SplFileInfo {
             $file = self::normalizePath($file, $basePath);
 
-            Assertion::false(
+            Assert::false(
                 is_link($file),
                 sprintf(
                     'Cannot add the link "%s": links are not supported.',
@@ -1136,10 +1133,10 @@ BANNER;
                 )
             );
 
-            Assertion::file(
+            Assert::file(
                 $file,
                 sprintf(
-                    '"%s" must contain a list of existing files. Could not find "%%s".',
+                    '"%s" must contain a list of existing files. Could not find %%s.',
                     $key
                 )
             );
@@ -1154,7 +1151,7 @@ BANNER;
      * @param string   $key           Config property name
      * @param string[] $excludedPaths
      *
-     * @return iterable|SplFileInfo[]
+     * @return iterable&(SplFileInfo[]&Finder)
      */
     private static function retrieveDirectories(
         stdClass $raw,
@@ -1280,11 +1277,7 @@ BANNER;
                 $method = trim($method);
                 $arguments = (array) $arguments;
 
-                Assertion::methodExists(
-                    $method,
-                    $finder,
-                    'The method "Finder::%s" does not exist.'
-                );
+                Assert::methodExists($finder, $method);
 
                 $normalizedConfig[$method] = $arguments;
             }
@@ -1297,7 +1290,7 @@ BANNER;
         $createNormalizedDirectories = static function (string $directory) use ($basePath): ?string {
             $directory = self::normalizePath($directory, $basePath);
 
-            Assertion::false(
+            Assert::false(
                 is_link($directory),
                 sprintf(
                     'Cannot append the link "%s" to the Finder: links are not supported.',
@@ -1305,7 +1298,7 @@ BANNER;
                 )
             );
 
-            Assertion::directory($directory);
+            Assert::directory($directory);
 
             return $directory;
         };
@@ -1317,7 +1310,7 @@ BANNER;
 
             $fileOrDirectory = self::normalizePath($fileOrDirectory, $basePath);
 
-            Assertion::false(
+            Assert::false(
                 is_link($fileOrDirectory),
                 sprintf(
                     'Cannot append the link "%s" to the Finder: links are not supported.',
@@ -1325,7 +1318,7 @@ BANNER;
                 )
             );
 
-            Assertion::true(
+            Assert::true(
                 file_exists($fileOrDirectory),
                 sprintf(
                     'Path "%s" was expected to be a file or directory. It may be a symlink (which are unsupported).',
@@ -1334,9 +1327,9 @@ BANNER;
             );
 
             if (false === is_file($fileOrDirectory)) {
-                Assertion::directory($fileOrDirectory);
+                Assert::directory($fileOrDirectory);
             } else {
-                Assertion::file($fileOrDirectory);
+                Assert::file($fileOrDirectory);
             }
 
             if (false === $blacklistFilter(new SplFileInfo($fileOrDirectory))) {
@@ -1392,12 +1385,20 @@ BANNER;
         }
 
         if (file_exists($vendorDir)) {
-            // The installed.json file is necessary for dumping the autoload correctly. Note however that it will not exists if no
-            // dependencies are included in the `composer.json`
-            $installedJsonFiles = self::normalizePath($vendorDir.'/composer/installed.json', $basePath);
+            // Note that some files may not exist. For example installed.json does not exist at all if no dependencies
+            // are included in composer.json.
+            $requiredComposerFiles = [
+                'installed.json',
+                'installed.php',
+                'InstalledVersions.php',
+            ];
 
-            if (file_exists($installedJsonFiles)) {
-                $filesToAppend[] = $installedJsonFiles;
+            foreach ($requiredComposerFiles as $requiredComposerFile) {
+                $normalizePath = self::normalizePath($vendorDir.'/composer/'.$requiredComposerFile, $basePath);
+
+                if (file_exists($normalizePath)) {
+                    $filesToAppend[] = $normalizePath;
+                }
             }
 
             $vendorPackages = toArray(values(map(
@@ -1490,7 +1491,7 @@ BANNER;
             return is_absolute_path($path)
                 ? canonicalize($path)
                 : self::normalizePath(trim($path, '/ '), $basePath)
-            ;
+                ;
         };
 
         if (array_key_exists('files', $autoload)) {
@@ -1498,8 +1499,8 @@ BANNER;
                 // @var string $path
                 $path = $normalizePath($path);
 
-                Assertion::file($path);
-                Assertion::false(is_link($path), 'Cannot add the link "'.$path.'": links are not supported.');
+                Assert::file($path);
+                Assert::false(is_link($path), 'Cannot add the link "'.$path.'": links are not supported.');
 
                 $filesToAppend[] = $path;
             }
@@ -1511,8 +1512,8 @@ BANNER;
         foreach ($paths as $path) {
             $path = $normalizePath($path);
 
-            Assertion::true(file_exists($path), 'File or directory "'.$path.'" was expected to exist.');
-            Assertion::false(is_link($path), 'Cannot add the link "'.$path.'": links are not supported.');
+            Assert::true(file_exists($path), 'File or directory "'.$path.'" was expected to exist.');
+            Assert::false(is_link($path), 'Cannot add the link "'.$path.'": links are not supported.');
 
             if (is_file($path)) {
                 $files[] = $path;
@@ -1538,7 +1539,7 @@ BANNER;
      * @param string[] $excludedPaths
      * @param string[] $devPackages
      *
-     * @return SplFileInfo[]
+     * @return Finder|SplFileInfo[]
      */
     private static function retrieveAllFiles(
         string $basePath,
@@ -1636,7 +1637,7 @@ BANNER;
                     $excludedPaths
                 ),
                 static function (string $path): bool {
-                    return '..' !== substr($path, 0, 2);
+                    return 0 !== strpos($path, '..');
                 }
             )
         );
@@ -1670,7 +1671,7 @@ BANNER;
         $normalizeDirectory = static function (string $directory) use ($basePath, $key): string {
             $directory = self::normalizePath($directory, $basePath);
 
-            Assertion::false(
+            Assert::false(
                 is_link($directory),
                 sprintf(
                     'Cannot add the link "%s": links are not supported.',
@@ -1678,10 +1679,10 @@ BANNER;
                 )
             );
 
-            Assertion::directory(
+            Assert::directory(
                 $directory,
                 sprintf(
-                    '"%s" must contain a list of existing directories. Could not find "%%s".',
+                    '"%s" must contain a list of existing directories. Could not find %%s.',
                     $key
                 )
             );
@@ -1791,25 +1792,52 @@ BANNER;
         return $raw->{self::EXCLUDE_COMPOSER_FILES_KEY} ?? true;
     }
 
-    /**
-     * @return Compactor[]
-     */
-    private static function retrieveCompactors(stdClass $raw, string $basePath, ConfigurationLogger $logger): array
+    private static function retrieveCompactors(stdClass $raw, string $basePath, ConfigurationLogger $logger): Compactors
     {
         self::checkIfDefaultValue($logger, $raw, self::COMPACTORS_KEY, []);
 
         $compactorClasses = array_unique((array) ($raw->{self::COMPACTORS_KEY} ?? []));
 
+        // Needs to do this check before returning the compactors in order to properly inform the users about
+        // possible misconfiguration
         $ignoredAnnotations = self::retrievePhpCompactorIgnoredAnnotations($raw, $compactorClasses, $logger);
 
         if (false === isset($raw->{self::COMPACTORS_KEY})) {
-            return [];
+            return new Compactors();
         }
 
-        $compactors = array_map(
+        $compactors = new Compactors(
+            ...self::createCompactors(
+                $raw,
+                $basePath,
+                $compactorClasses,
+                $ignoredAnnotations,
+                $logger
+            )
+        );
+
+        self::checkCompactorsOrder($logger, $compactors);
+
+        return $compactors;
+    }
+
+    /**
+     * @param string[] $compactorClasses
+     * @param string[] $ignoredAnnotations
+     *
+     * @return Compactor[]
+     */
+    private static function createCompactors(
+        stdClass $raw,
+        string $basePath,
+        array $compactorClasses,
+        array $ignoredAnnotations,
+        ConfigurationLogger $logger
+    ): array {
+        return array_map(
             static function (string $class) use ($raw, $basePath, $logger, $ignoredAnnotations): Compactor {
-                Assertion::classExists($class, 'The compactor class "%s" does not exist.');
-                Assertion::implementsInterface($class, Compactor::class, 'The class "%s" is not a compactor class.');
+                Assert::classExists($class, 'The compactor class %s does not exist.');
+                Assert::isAOf($class, Compactor::class, sprintf('The class "%s" is not a compactor class.', $class));
 
                 if (LegacyPhp::class === $class) {
                     $logger->addRecommendation(
@@ -1843,10 +1871,13 @@ BANNER;
             },
             $compactorClasses
         );
+    }
 
+    private static function checkCompactorsOrder(ConfigurationLogger $logger, Compactors $compactors): void
+    {
         $scoperCompactor = false;
 
-        foreach ($compactors as $compactor) {
+        foreach ($compactors->toArray() as $compactor) {
             if ($compactor instanceof PhpScoperCompactor) {
                 $scoperCompactor = true;
             }
@@ -1854,18 +1885,14 @@ BANNER;
             if ($compactor instanceof PhpCompactor) {
                 if (true === $scoperCompactor) {
                     $logger->addRecommendation(
-                        sprintf(
-                            'The PHP compactor has been registered after the PhpScoper compactor. It is '
-                            .'recommended to register the PHP compactor before for a clearer code and faster processing.'
-                        )
+                        'The PHP compactor has been registered after the PhpScoper compactor. It is '
+                        .'recommended to register the PHP compactor before for a clearer code and faster processing.'
                     );
                 }
 
                 break;
             }
         }
-
-        return $compactors;
     }
 
     private static function retrieveCompressionAlgorithm(stdClass $raw, ConfigurationLogger $logger): ?int
@@ -1878,11 +1905,11 @@ BANNER;
 
         $knownAlgorithmNames = array_keys(get_phar_compression_algorithms());
 
-        Assertion::inArray(
+        Assert::inArray(
             $raw->{self::COMPRESSION_KEY},
             $knownAlgorithmNames,
             sprintf(
-                'Invalid compression algorithm "%%s", use one of "%s" instead.',
+                'Invalid compression algorithm %%s, use one of "%s" instead.',
                 implode('", "', $knownAlgorithmNames)
             )
         );
@@ -1955,7 +1982,7 @@ BANNER;
         }
 
         if (is_bool($main)) {
-            Assertion::false(
+            Assert::false(
                 $main,
                 'Cannot "enable" a main script: either disable it with `false` or give the main script file path.'
             );
@@ -1963,7 +1990,7 @@ BANNER;
             return null;
         }
 
-        Assertion::file($main);
+        Assert::file($main);
 
         return $main;
     }
@@ -2028,9 +2055,8 @@ BANNER;
         }
 
         $map = [];
-        $rawMap = (array) $raw->{self::MAP_KEY};
 
-        foreach ($rawMap as $item) {
+        foreach ((array) $raw->{self::MAP_KEY} as $item) {
             $processed = [];
 
             foreach ($item as $match => $replace) {
@@ -2125,7 +2151,7 @@ BANNER;
         }
 
         if (!isset($raw->{self::KEY_KEY})) {
-            Assertion::true(
+            Assert::true(
                 Phar::OPENSSL !== $signingAlgorithm,
                 'Expected to have a private key for OpenSSL signing but none have been provided.'
             );
@@ -2135,7 +2161,7 @@ BANNER;
 
         $path = self::normalizePath($raw->{self::KEY_KEY}, $basePath);
 
-        Assertion::file($path);
+        Assert::file($path);
 
         return $path;
     }
@@ -2181,8 +2207,12 @@ BANNER;
     /**
      * @return scalar[]
      */
-    private static function retrieveReplacements(stdClass $raw, ?string $file, ConfigurationLogger $logger): array
-    {
+    private static function retrieveReplacements(
+        stdClass $raw,
+        ?string $file,
+        string $path,
+        ConfigurationLogger $logger
+    ): array {
         self::checkIfDefaultValue($logger, $raw, self::REPLACEMENTS_KEY, new stdClass());
 
         if (null === $file) {
@@ -2192,23 +2222,23 @@ BANNER;
         $replacements = isset($raw->{self::REPLACEMENTS_KEY}) ? (array) $raw->{self::REPLACEMENTS_KEY} : [];
 
         if (null !== ($git = self::retrievePrettyGitPlaceholder($raw, $logger))) {
-            $replacements[$git] = self::retrievePrettyGitTag($file);
+            $replacements[$git] = self::retrievePrettyGitTag($path);
         }
 
         if (null !== ($git = self::retrieveGitHashPlaceholder($raw, $logger))) {
-            $replacements[$git] = self::retrieveGitHash($file);
+            $replacements[$git] = self::retrieveGitHash($path);
         }
 
         if (null !== ($git = self::retrieveGitShortHashPlaceholder($raw, $logger))) {
-            $replacements[$git] = self::retrieveGitHash($file, true);
+            $replacements[$git] = self::retrieveGitHash($path, true);
         }
 
         if (null !== ($git = self::retrieveGitTagPlaceholder($raw, $logger))) {
-            $replacements[$git] = self::retrieveGitTag($file);
+            $replacements[$git] = self::retrieveGitTag($path);
         }
 
         if (null !== ($git = self::retrieveGitVersionPlaceholder($raw, $logger))) {
-            $replacements[$git] = self::retrieveGitVersion($file);
+            $replacements[$git] = self::retrieveGitVersion($path);
         }
 
         /**
@@ -2254,14 +2284,14 @@ BANNER;
      *
      * @return string the commit hash
      */
-    private static function retrieveGitHash(string $file, bool $short = false): string
+    private static function retrieveGitHash(string $path, bool $short = false): string
     {
         return self::runGitCommand(
             sprintf(
                 'git log --pretty="%s" -n1 HEAD',
                 $short ? '%h' : '%H'
             ),
-            $file
+            $path
         );
     }
 
@@ -2282,14 +2312,14 @@ BANNER;
         return $raw->{$key} ?? null;
     }
 
-    private static function retrieveGitTag(string $file): string
+    private static function retrieveGitTag(string $path): string
     {
-        return self::runGitCommand('git describe --tags HEAD', $file);
+        return self::runGitCommand('git describe --tags HEAD', $path);
     }
 
-    private static function retrievePrettyGitTag(string $file): string
+    private static function retrievePrettyGitTag(string $path): string
     {
-        $version = self::retrieveGitTag($file);
+        $version = self::retrieveGitTag($path);
 
         if (preg_match('/^(?<tag>.+)-\d+-g(?<hash>[a-f0-9]{7})$/', $version, $matches)) {
             return sprintf('%s@%s', $matches['tag'], $matches['hash']);
@@ -2303,18 +2333,18 @@ BANNER;
         return self::retrievePlaceholder($raw, $logger, self::GIT_VERSION_KEY);
     }
 
-    private static function retrieveGitVersion(string $file): ?string
+    private static function retrieveGitVersion(string $path): ?string
     {
         try {
-            return self::retrieveGitTag($file);
+            return self::retrieveGitTag($path);
         } catch (RuntimeException $exception) {
             try {
-                return self::retrieveGitHash($file, true);
+                return self::retrieveGitHash($path, true);
             } catch (RuntimeException $exception) {
                 throw new RuntimeException(
                     sprintf(
                         'The tag or commit hash could not be retrieved from "%s": %s',
-                        dirname($file),
+                        $path,
                         $exception->getMessage()
                     ),
                     0,
@@ -2331,9 +2361,7 @@ BANNER;
 
     private static function retrieveDatetimeNow(string $format): string
     {
-        $now = new DateTimeImmutable('now', new DateTimeZone('UTC'));
-
-        return $now->format($format);
+        return (new DateTimeImmutable('now', new DateTimeZone('UTC')))->format($format);
     }
 
     private static function retrieveDatetimeFormat(stdClass $raw, ConfigurationLogger $logger): array
@@ -2368,7 +2396,7 @@ BANNER;
         if (null !== $format) {
             $formattedDate = (new DateTimeImmutable())->format($format);
 
-            Assertion::false(
+            Assert::false(
                 false === $formattedDate || $formattedDate === $format,
                 sprintf(
                     'Expected the datetime format to be a valid format: "%s" is not',
@@ -2411,13 +2439,13 @@ BANNER;
             return null;
         }
 
-        Assertion::string($shebang, 'Expected shebang to be either a string, false or null, found true');
+        Assert::string($shebang, 'Expected shebang to be either a string, false or null, found true');
 
         $shebang = trim($shebang);
 
-        Assertion::notEmpty($shebang, 'The shebang should not be empty.');
-        Assertion::true(
-            '#!' === substr($shebang, 0, 2),
+        Assert::notEmpty($shebang, 'The shebang should not be empty.');
+        Assert::true(
+            0 === strpos($shebang, '#!'),
             sprintf(
                 'The shebang line must start with "#!". Got "%s" instead',
                 $shebang
@@ -2449,9 +2477,9 @@ BANNER;
 
         $algorithm = strtoupper($raw->{self::ALGORITHM_KEY});
 
-        Assertion::inArray($algorithm, array_keys(get_phar_signing_algorithms()));
+        Assert::inArray($algorithm, array_keys(get_phar_signing_algorithms()));
 
-        Assertion::true(
+        Assert::true(
             defined('Phar::'.$algorithm),
             sprintf(
                 'The signing algorithm "%s" is not supported by your current PHAR version.',
@@ -2492,7 +2520,7 @@ BANNER;
             return null;
         }
 
-        Assertion::true(is_string($banner) || is_array($banner), 'The banner cannot accept true as a value');
+        Assert::true(is_string($banner) || is_array($banner), 'The banner cannot accept true as a value');
 
         if (is_array($banner)) {
             $banner = implode("\n", $banner);
@@ -2529,7 +2557,7 @@ BANNER;
 
         $bannerFile = make_path_absolute($raw->{self::BANNER_FILE_KEY}, $basePath);
 
-        Assertion::file($bannerFile);
+        Assert::file($bannerFile);
 
         if (false === $stubIsGenerated) {
             $logger->addWarning(
@@ -2562,7 +2590,7 @@ BANNER;
         if (isset($raw->{self::STUB_KEY}) && is_string($raw->{self::STUB_KEY})) {
             $stubPath = make_path_absolute($raw->{self::STUB_KEY}, $basePath);
 
-            Assertion::file($stubPath);
+            Assert::file($stubPath);
 
             return $stubPath;
         }
@@ -2667,23 +2695,40 @@ BANNER;
 
         if (!isset($raw->{self::PHP_SCOPER_KEY})) {
             $configFilePath = make_path_absolute(self::PHP_SCOPER_CONFIG, $basePath);
+            $configFilePath = file_exists($configFilePath) ? $configFilePath : null;
 
-            return file_exists($configFilePath)
-                ? PhpScoperConfiguration::load($configFilePath)
-                : PhpScoperConfiguration::load()
-             ;
+            return self::createPhpScoperConfig($configFilePath);
         }
 
         $configFile = $raw->{self::PHP_SCOPER_KEY};
 
-        Assertion::string($configFile);
+        Assert::string($configFile);
 
         $configFilePath = make_path_absolute($configFile, $basePath);
 
-        Assertion::file($configFilePath);
-        Assertion::readable($configFilePath);
+        Assert::file($configFilePath);
+        Assert::readable($configFilePath);
 
-        return PhpScoperConfiguration::load($configFilePath);
+        return self::createPhpScoperConfig($configFilePath);
+    }
+
+    private static function createPhpScoperConfig(?string $filePath): PhpScoperConfiguration
+    {
+        $configFactory = (new Container())->getConfigurationFactory();
+
+        try {
+            return $configFactory->create($filePath);
+        } catch (Throwable $throwable) {
+            throw new InvalidArgumentException(
+                sprintf(
+                    'Could not create a PHP-Scoper config from the file "%s": %s',
+                    $filePath,
+                    $throwable->getMessage(),
+                ),
+                $throwable->getCode(),
+                $throwable,
+            );
+        }
     }
 
     /**
@@ -2691,10 +2736,8 @@ BANNER;
      *
      * @return string The trimmed output from the command
      */
-    private static function runGitCommand(string $command, string $file): string
+    private static function runGitCommand(string $command, string $path): string
     {
-        $path = dirname($file);
-
         $process = Process::fromShellCommandline($command, $path);
 
         if (0 === $process->run()) {
@@ -2720,7 +2763,10 @@ BANNER;
         array $compactorClasses,
         ConfigurationLogger $logger
     ): array {
-        $hasPhpCompactor = in_array(PhpCompactor::class, $compactorClasses, true) || in_array(LegacyPhp::class, $compactorClasses, true);
+        $hasPhpCompactor = (
+            in_array(PhpCompactor::class, $compactorClasses, true)
+            || in_array(LegacyPhp::class, $compactorClasses, true)
+        );
 
         self::checkIfDefaultValue($logger, $raw, self::ANNOTATIONS_KEY, true);
         self::checkIfDefaultValue($logger, $raw, self::ANNOTATIONS_KEY, null);
@@ -2791,48 +2837,57 @@ BANNER;
 
         return new PhpCompactor(
             new DocblockAnnotationParser(
-                new DocblockParser(),
-                new AnnotationDumper(),
+                DocBlockFactory::createInstance(),
+                new CompactedFormatter(),
                 $ignoredAnnotations
             )
         );
     }
 
-    private static function createPhpScoperCompactor(stdClass $raw, string $basePath, ConfigurationLogger $logger): Compactor
-    {
-        $phpScoperConfig = self::retrievePhpScoperConfig($raw, $basePath, $logger);
+    private static function createPhpScoperCompactor(
+        stdClass $raw,
+        string $basePath,
+        ConfigurationLogger $logger
+    ): Compactor {
+        $phpScoperConfig = self::configurePhpScoperPrefix(
+            self::retrievePhpScoperConfig($raw, $basePath, $logger),
+        );
 
-        $phpScoper = (new class() extends ApplicationFactory {
-            public static function createScoper(): Scoper
-            {
-                return parent::createScoper();
-            }
-        })::createScoper();
-
-        if ([] !== $phpScoperConfig->getWhitelistedFiles()) {
-            $whitelistedFiles = array_values(
-                array_unique(
-                    array_map(
-                        static function (string $path) use ($basePath): string {
-                            return make_path_relative($path, $basePath);
-                        },
-                        $phpScoperConfig->getWhitelistedFiles()
-                    )
+        $whitelistedFiles = array_values(
+            array_unique(
+                array_map(
+                    static function (string $path) use ($basePath): string {
+                        return make_path_relative($path, $basePath);
+                    },
+                    array_keys(
+                        $phpScoperConfig->getExcludedFilesWithContents(),
+                    ),
                 )
-            );
-
-            $phpScoper = new FileWhitelistScoper($phpScoper, ...$whitelistedFiles);
-        }
-
-        $prefix = $phpScoperConfig->getPrefix() ?? unique_id('_HumbugBox');
+            )
+        );
 
         return new PhpScoperCompactor(
-            new SimpleScoper(
-                $phpScoper,
-                $prefix,
-                $phpScoperConfig->getWhitelist(),
-                $phpScoperConfig->getPatchers()
-            )
+            new SimpleScoper($phpScoperConfig, ...$whitelistedFiles)
+        );
+    }
+
+    private static function configurePhpScoperPrefix(PhpScoperConfiguration $phpScoperConfig): PhpScoperConfiguration
+    {
+        $prefix = $phpScoperConfig->getPrefix();
+
+        if (!str_starts_with($prefix, '_PhpScoper')) {
+            return $phpScoperConfig;
+        }
+
+        // TODO: provide easier way to change the prefix
+        //  https://github.com/humbug/php-scoper/issues/616
+        return new PhpScoperConfiguration(
+            $phpScoperConfig->getPath(),
+            unique_id('_HumbugBox'),
+            $phpScoperConfig->getFilesWithContents(),
+            $phpScoperConfig->getExcludedFilesWithContents(),
+            $phpScoperConfig->getPatcher(),
+            $phpScoperConfig->getSymbolsConfiguration(),
         );
     }
 
