@@ -1,32 +1,32 @@
 <?php
 
-namespace _HumbugBox87c495005ea2\KevinGH\RequirementChecker;
+namespace HumbugBox3141\KevinGH\RequirementChecker;
 
 use ArrayIterator;
 use Countable;
 use IteratorAggregate;
+use ReturnTypeWillChange;
 use Traversable;
-/**
-@symfony
-*/
-final class RequirementCollection implements \IteratorAggregate, \Countable
+final class RequirementCollection implements IteratorAggregate, Countable
 {
     private $requirements = array();
+    #[ReturnTypeWillChange]
     public function getIterator()
     {
-        return new \ArrayIterator($this->requirements);
+        return new ArrayIterator($this->requirements);
     }
+    #[ReturnTypeWillChange]
     public function count()
     {
         return \count($this->requirements);
     }
-    public function add(\_HumbugBox87c495005ea2\KevinGH\RequirementChecker\Requirement $requirement)
+    public function add(Requirement $requirement)
     {
         $this->requirements[] = $requirement;
     }
     public function addRequirement($checkIsFulfilled, $testMessage, $helpText)
     {
-        $this->add(new \_HumbugBox87c495005ea2\KevinGH\RequirementChecker\Requirement($checkIsFulfilled, $testMessage, $helpText));
+        $this->add(new Requirement($checkIsFulfilled, $testMessage, $helpText));
     }
     public function getRequirements()
     {
@@ -38,7 +38,7 @@ final class RequirementCollection implements \IteratorAggregate, \Countable
     }
     public function evaluateRequirements()
     {
-        return \array_reduce($this->requirements, function ($checkPassed, \_HumbugBox87c495005ea2\KevinGH\RequirementChecker\Requirement $requirement) {
+        return \array_reduce($this->requirements, function ($checkPassed, Requirement $requirement) {
             return $checkPassed && $requirement->isFulfilled();
         }, \true);
     }
