@@ -16,9 +16,9 @@ namespace KevinGH\Box\Configuration;
 
 use function chdir;
 use const DIRECTORY_SEPARATOR;
+use function file_get_contents;
 use Generator;
-use function Humbug\get_contents;
-use function Humbug\PhpScoper\json_decode;
+use function Safe\json_decode;
 use InvalidArgumentException;
 use function KevinGH\Box\FileSystem\dump_file;
 use function KevinGH\Box\FileSystem\make_path_absolute;
@@ -1130,7 +1130,7 @@ JSON
 
             $this->fail('Expected exception to be thrown.');
         } catch (JsonValidationException $exception) {
-            $this->assertRegExp(
+            $this->assertMatchesRegularExpression(
                 '/does not match the expected JSON schema:/',
                 $exception->getMessage()
             );
@@ -1190,7 +1190,7 @@ JSON
 
             $this->fail('Expected exception to be thrown.');
         } catch (JsonValidationException $exception) {
-            $this->assertRegExp(
+            $this->assertMatchesRegularExpression(
                 '/does not match the expected JSON schema:/',
                 $exception->getMessage()
             );
@@ -1224,7 +1224,7 @@ JSON
 
             $this->fail('Expected exception to be thrown.');
         } catch (JsonValidationException $exception) {
-            $this->assertRegExp(
+            $this->assertMatchesRegularExpression(
                 '/does not match the expected JSON schema:/',
                 $exception->getMessage()
             );
@@ -1271,7 +1271,7 @@ JSON
 
             $this->fail('Expected exception to be thrown.');
         } catch (JsonValidationException $exception) {
-            $this->assertRegExp(
+            $this->assertMatchesRegularExpression(
                 '/does not match the expected JSON schema:/',
                 $exception->getMessage()
             );
@@ -1305,7 +1305,7 @@ JSON
 
             $this->fail('Expected exception to be thrown.');
         } catch (JsonValidationException $exception) {
-            $this->assertRegExp(
+            $this->assertMatchesRegularExpression(
                 '/does not match the expected JSON schema:/',
                 $exception->getMessage()
             );
@@ -1353,7 +1353,7 @@ JSON
 
             $this->fail('Expected exception to be thrown.');
         } catch (JsonValidationException $exception) {
-            $this->assertRegExp(
+            $this->assertMatchesRegularExpression(
                 '/does not match the expected JSON schema:/',
                 $exception->getMessage()
             );
@@ -1430,21 +1430,13 @@ JSON
             'sub-dir/rab',
         ];
 
-        $this->assertEquals(
+        $this->assertEqualsCanonicalizing(
             $expected,
-            $this->normalizePaths($this->config->getFiles()),
-            '',
-            .0,
-            10,
-            true
+            $this->normalizePaths($this->config->getFiles())
         );
-        $this->assertEquals(
+        $this->assertEqualsCanonicalizing(
             $expected,
-            $this->normalizePaths($this->config->getBinaryFiles()),
-            '',
-            .0,
-            10,
-            true
+            $this->normalizePaths($this->config->getBinaryFiles())
         );
     }
 
@@ -1468,21 +1460,13 @@ JSON
         // Relative to the current working directory for readability
         $expected = ['A/foo'];
 
-        $this->assertEquals(
+        $this->assertEqualsCanonicalizing(
             $expected,
-            $this->normalizePaths($this->config->getFiles()),
-            '',
-            .0,
-            10,
-            true
+            $this->normalizePaths($this->config->getFiles())
         );
-        $this->assertEquals(
+        $this->assertEqualsCanonicalizing(
             $expected,
-            $this->normalizePaths($this->config->getBinaryFiles()),
-            '',
-            .0,
-            10,
-            true
+            $this->normalizePaths($this->config->getBinaryFiles())
         );
     }
 
@@ -1531,7 +1515,7 @@ JSON
             $this->fail('Expected exception to be thrown.');
         } catch (InvalidArgumentException $exception) {
             $this->assertSame(
-                'The method "Finder::invalidMethod" does not exist.',
+                'Expected the method "invalidMethod" to exist.',
                 $exception->getMessage()
             );
         }
@@ -1759,7 +1743,10 @@ JSON
 
     public function test_no_warning_is_given_when_no_installed_json_no_composer_lock_are_found(): void
     {
-        $config = Configuration::create($configPath = self::FIXTURES_DIR.'/dir000/box.json', json_decode(get_contents($configPath)));
+        $config = Configuration::create(
+            $configPath = self::FIXTURES_DIR.'/dir000/box.json',
+            json_decode(file_get_contents($configPath), false)
+        );
 
         $this->assertSame([], $config->getRecommendations());
         $this->assertSame([], $config->getWarnings());
@@ -1767,7 +1754,10 @@ JSON
 
     public function test_no_warning_is_given_when_the_installed_json_and_composer_lock_are_found(): void
     {
-        $config = Configuration::create($configPath = self::FIXTURES_DIR.'/dir001/box.json', json_decode(get_contents($configPath)));
+        $config = Configuration::create(
+            $configPath = self::FIXTURES_DIR.'/dir001/box.json',
+            json_decode(file_get_contents($configPath), false)
+        );
 
         $this->assertTrue($config->dumpAutoload());
 
@@ -1777,7 +1767,7 @@ JSON
 
     public function test_no_warning_is_given_when_the_installed_json_is_found_and_the_composer_lock_is_not_when_the_composer_autoloader_is_not_dumped(): void
     {
-        $config = Configuration::create($configPath = self::FIXTURES_DIR.'/dir002/box.json', json_decode(get_contents($configPath)));
+        $config = Configuration::create($configPath = self::FIXTURES_DIR.'/dir002/box.json', json_decode(file_get_contents($configPath)));
 
         $this->assertFalse($config->dumpAutoload());
 
@@ -1787,7 +1777,7 @@ JSON
 
     public function test_a_warning_is_given_when_no_installed_json_is_found_and_the_composer_lock_is_when_the_composer_autoloader_is_dumped(): void
     {
-        $decodedConfig = json_decode(get_contents($configPath = self::FIXTURES_DIR.'/dir002/box.json'));
+        $decodedConfig = json_decode(file_get_contents($configPath = self::FIXTURES_DIR.'/dir002/box.json'));
         $decodedConfig->{'dump-autoload'} = true;
 
         $config = Configuration::create($configPath, $decodedConfig);
@@ -1808,7 +1798,7 @@ JSON
     {
         $configPath = self::FIXTURES_DIR.'/dir003/box.json';
 
-        $decodedConfig = json_decode(get_contents($configPath));
+        $decodedConfig = json_decode(file_get_contents($configPath));
         unset($decodedConfig->{'dump-autoload'});
 
         $config = Configuration::create($configPath, $decodedConfig);
@@ -1821,7 +1811,7 @@ JSON
 
     public function test_a_warning_is_given_when_the_installed_json_is_found_and_the_composer_lock_is_not(): void
     {
-        $config = Configuration::create($configPath = self::FIXTURES_DIR.'/dir003/box.json', json_decode(get_contents($configPath)));
+        $config = Configuration::create($configPath = self::FIXTURES_DIR.'/dir003/box.json', json_decode(file_get_contents($configPath)));
 
         $this->assertFalse($config->dumpAutoload());
 
@@ -1837,7 +1827,7 @@ JSON
 
     public function test_no_warning_is_given_when_the_installed_json_is_found_and_the_composer_lock_is_not_and_the_dump_autoload_disabled(): void
     {
-        $config = Configuration::create($configPath = self::FIXTURES_DIR.'/dir004/box.json', json_decode(get_contents($configPath)));
+        $config = Configuration::create($configPath = self::FIXTURES_DIR.'/dir004/box.json', json_decode(file_get_contents($configPath)));
 
         $this->assertFalse($config->dumpAutoload());
 
