@@ -23,7 +23,6 @@ use function extension_loaded;
 use function file_get_contents;
 use Generator;
 use function get_loaded_extensions;
-use function Humbug\get_contents;
 use function implode;
 use InvalidArgumentException;
 use function iterator_to_array;
@@ -47,6 +46,8 @@ use KevinGH\Box\Test\RequiresPharReadonlyOff;
 use function mt_getrandmax;
 use Phar;
 use PharFileInfo;
+use const PHP_EOL;
+use const PHP_OS;
 use const PHP_VERSION;
 use function phpversion;
 use function preg_match;
@@ -61,7 +62,6 @@ use function strlen;
 use function substr;
 use Symfony\Component\Console\Command\Command;
 use Symfony\Component\Console\Output\OutputInterface;
-use Symfony\Component\Console\Tester\CommandTester;
 use Symfony\Component\Finder\Finder;
 use Symfony\Component\Process\PhpExecutableFinder;
 use Traversable;
@@ -88,19 +88,7 @@ class CompileTest extends CommandTestCase
 
         parent::setUp();
 
-        $this->commandTester = new class($this->application->get($this->getCommand()->getName())) extends CommandTester {
-            /**
-             * {@inheritdoc}
-             */
-            public function execute(array $input, array $options = [])
-            {
-                if ('compile' === $input['command']) {
-                    $input['--no-parallel'] = null;
-                }
-
-                return parent::execute($input, $options);
-            }
-        };
+        $this->commandTester = new CommandTester($this->application->get($this->getCommand()->getName()));
 
         remove(self::FIXTURES_DIR.'/dir010/index.phar');
     }
@@ -113,7 +101,7 @@ class CompileTest extends CommandTestCase
         return new Compile();
     }
 
-    public function test_it_can_build_a_PHAR_file(): void
+    public function test_it_can_build_a_phar_file(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
@@ -123,6 +111,8 @@ class CompileTest extends CommandTestCase
 
         $shebang = sprintf('#!%s', (new PhpExecutableFinder())->find());
 
+        $numberOfFiles = 47;
+
         dump_file(
             'box.json',
             json_encode(
@@ -205,7 +195,7 @@ Box version 3.x-dev@151e40a
 No recommendation found.
 No warning found.
 
- // PHAR: 44 files (100B)
+ // PHAR: $numberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -260,8 +250,6 @@ PHP;
             '/.box/.requirements.php',
             '/.box/bin/',
             '/.box/bin/check-requirements.php',
-            '/.box/composer.json',
-            '/.box/composer.lock',
             '/.box/src/',
             '/.box/src/Checker.php',
             '/.box/src/IO.php',
@@ -276,23 +264,28 @@ PHP;
             '/.box/vendor/autoload.php',
             '/.box/vendor/composer/',
             '/.box/vendor/composer/ClassLoader.php',
+            '/.box/vendor/composer/InstalledVersions.php',
+            '/.box/vendor/composer/installed.php',
             '/.box/vendor/composer/LICENSE',
             '/.box/vendor/composer/autoload_classmap.php',
             '/.box/vendor/composer/autoload_namespaces.php',
             '/.box/vendor/composer/autoload_psr4.php',
             '/.box/vendor/composer/autoload_real.php',
             '/.box/vendor/composer/autoload_static.php',
-            '/.box/vendor/composer/installed.json',
             '/.box/vendor/composer/semver/',
             '/.box/vendor/composer/semver/LICENSE',
             '/.box/vendor/composer/semver/src/',
             '/.box/vendor/composer/semver/src/Comparator.php',
+            '/.box/vendor/composer/semver/src/CompilingMatcher.php',
             '/.box/vendor/composer/semver/src/Constraint/',
-            '/.box/vendor/composer/semver/src/Constraint/AbstractConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/Bound.php',
             '/.box/vendor/composer/semver/src/Constraint/Constraint.php',
             '/.box/vendor/composer/semver/src/Constraint/ConstraintInterface.php',
-            '/.box/vendor/composer/semver/src/Constraint/EmptyConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/MatchAllConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/MatchNoneConstraint.php',
             '/.box/vendor/composer/semver/src/Constraint/MultiConstraint.php',
+            '/.box/vendor/composer/semver/src/Interval.php',
+            '/.box/vendor/composer/semver/src/Intervals.php',
             '/.box/vendor/composer/semver/src/Semver.php',
             '/.box/vendor/composer/semver/src/VersionParser.php',
             '/one/',
@@ -317,10 +310,10 @@ PHP;
 
         $actualFiles = $this->retrievePharFiles($phar);
 
-        $this->assertSame($expectedFiles, $actualFiles);
+        $this->assertEqualsCanonicalizing($expectedFiles, $actualFiles);
     }
 
-    public function test_it_can_build_a_PHAR_from_a_different_directory(): void
+    public function test_it_can_build_a_phar_from_a_different_directory(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
@@ -370,7 +363,7 @@ PHP;
         );
     }
 
-    public function test_it_can_build_a_PHAR_without_any_configuration(): void
+    public function test_it_can_build_a_phar_without_any_configuration(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
@@ -382,6 +375,7 @@ PHP;
         );
 
         $version = get_box_version();
+        $expectedNumberOfFiles = 51;
 
         $expected = <<<OUTPUT
 
@@ -422,7 +416,7 @@ Box version 3.x-dev@151e40a
 No recommendation found.
 No warning found.
 
- // PHAR: 48 files (100B)
+ // PHAR: $expectedNumberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -483,8 +477,6 @@ PHP;
             '/.box/.requirements.php',
             '/.box/bin/',
             '/.box/bin/check-requirements.php',
-            '/.box/composer.json',
-            '/.box/composer.lock',
             '/.box/src/',
             '/.box/src/Checker.php',
             '/.box/src/IO.php',
@@ -499,23 +491,28 @@ PHP;
             '/.box/vendor/autoload.php',
             '/.box/vendor/composer/',
             '/.box/vendor/composer/ClassLoader.php',
+            '/.box/vendor/composer/InstalledVersions.php',
+            '/.box/vendor/composer/installed.php',
             '/.box/vendor/composer/LICENSE',
             '/.box/vendor/composer/autoload_classmap.php',
             '/.box/vendor/composer/autoload_namespaces.php',
             '/.box/vendor/composer/autoload_psr4.php',
             '/.box/vendor/composer/autoload_real.php',
             '/.box/vendor/composer/autoload_static.php',
-            '/.box/vendor/composer/installed.json',
             '/.box/vendor/composer/semver/',
             '/.box/vendor/composer/semver/LICENSE',
             '/.box/vendor/composer/semver/src/',
             '/.box/vendor/composer/semver/src/Comparator.php',
+            '/.box/vendor/composer/semver/src/CompilingMatcher.php',
             '/.box/vendor/composer/semver/src/Constraint/',
-            '/.box/vendor/composer/semver/src/Constraint/AbstractConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/Bound.php',
             '/.box/vendor/composer/semver/src/Constraint/Constraint.php',
             '/.box/vendor/composer/semver/src/Constraint/ConstraintInterface.php',
-            '/.box/vendor/composer/semver/src/Constraint/EmptyConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/MatchAllConstraint.php',
+            '/.box/vendor/composer/semver/src/Constraint/MatchNoneConstraint.php',
             '/.box/vendor/composer/semver/src/Constraint/MultiConstraint.php',
+            '/.box/vendor/composer/semver/src/Interval.php',
+            '/.box/vendor/composer/semver/src/Intervals.php',
             '/.box/vendor/composer/semver/src/Semver.php',
             '/.box/vendor/composer/semver/src/VersionParser.php',
             '/binary',
@@ -543,7 +540,7 @@ PHP;
 
         $actualFiles = $this->retrievePharFiles($phar);
 
-        $this->assertSame($expectedFiles, $actualFiles);
+        $this->assertEqualsCanonicalizing($expectedFiles, $actualFiles);
 
         unset($phar);
         Phar::unlinkArchive('index.phar');
@@ -561,7 +558,7 @@ PHP;
         );
     }
 
-    public function test_it_can_build_a_PHAR_with_complete_mapping(): void
+    public function test_it_can_build_a_phar_with_complete_mapping(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
@@ -718,10 +715,10 @@ PHP;
 
         $actualFiles = $this->retrievePharFiles($phar);
 
-        $this->assertSame($expectedFiles, $actualFiles);
+        $this->assertEqualsCanonicalizing($expectedFiles, $actualFiles);
     }
 
-    public function test_it_can_build_a_PHAR_with_complete_mapping_without_an_alias(): void
+    public function test_it_can_build_a_phar_with_complete_mapping_without_an_alias(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
@@ -795,12 +792,15 @@ PHP;
         $this->assertSame($expectedStub, $actualStub);
     }
 
-    public function test_it_can_build_a_PHAR_file_in_verbose_mode(): void
+    public function test_it_can_build_a_phar_file_in_verbose_mode(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
         $shebang = sprintf('#!%s', (new PhpExecutableFinder())->find());
 
+        $expectedNumberOfClasses = 1;
+        $expectedNumberOfFiles = 47;
+
         dump_file(
             'box.json',
             json_encode(
@@ -874,7 +874,8 @@ Box version 3.x-dev@151e40a
 )
 ? Dumping the Composer autoloader
     > '/usr/local/bin/composer' 'dump-autoload' '--classmap-authoritative' '--no-dev'
-Generating optimized autoload files (authoritative)\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08Generated optimized autoload files (authoritative) containing 0 classes
+Generating optimized autoload files (authoritative)
+Generated optimized autoload files (authoritative) containing $expectedNumberOfClasses classes
 
 ? Removing the Composer dump artefacts
 ? No compression
@@ -889,7 +890,7 @@ Generating optimized autoload files (authoritative)\x08\x08\x08\x08\x08\x08\x08\
 No recommendation found.
 No warning found.
 
- // PHAR: 44 files (100B)
+ // PHAR: $expectedNumberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -908,12 +909,15 @@ OUTPUT;
         $this->assertSame($expected, $actual);
     }
 
-    public function test_it_can_build_a_PHAR_file_in_very_verbose_mode(): void
+    public function test_it_can_build_a_phar_file_in_very_verbose_mode(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
         $shebang = sprintf('#!%s', (new PhpExecutableFinder())->find());
 
+        $expectedNumberOfClasses = 1;
+        $expectedNumberOfFiles = 47;
+
         dump_file(
             'box.json',
             json_encode(
@@ -991,7 +995,8 @@ Box version 3.x-dev@151e40a
 )
 ? Dumping the Composer autoloader
     > '/usr/local/bin/composer' 'dump-autoload' '--classmap-authoritative' '--no-dev' '-v'
-Generating optimized autoload files (authoritative)\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08\x08Generated optimized autoload files (authoritative) containing 0 classes
+Generating optimized autoload files (authoritative)
+Generated optimized autoload files (authoritative) containing $expectedNumberOfClasses classes
 
 ? Removing the Composer dump artefacts
 ? No compression
@@ -1006,7 +1011,7 @@ Generating optimized autoload files (authoritative)\x08\x08\x08\x08\x08\x08\x08\
 No recommendation found.
 No warning found.
 
- // PHAR: 44 files (100B)
+ // PHAR: $expectedNumberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -1031,7 +1036,7 @@ OUTPUT;
         $this->assertSame($expected, $actual);
     }
 
-    public function test_it_can_build_a_PHAR_file_in_debug_mode(): void
+    public function test_it_can_build_a_phar_file_in_debug_mode(): void
     {
         dump_file(
             'index.php',
@@ -1054,7 +1059,7 @@ PHP
 JSON
         );
 
-        $this->assertDirectoryNotExists('.box_dump');
+        $this->assertDirectoryDoesNotExist('.box_dump');
 
         $this->commandTester->execute(
             [
@@ -1085,9 +1090,9 @@ JSON
         );
 
         $expected = <<<OUTPUT
+$memoryLog
 [debug] Checking BOX_ALLOW_XDEBUG
 $xdebugLog
-$memoryLog
 [debug] Disabled parallel processing
 
     ____
@@ -1151,7 +1156,7 @@ OUTPUT;
             )
         );
 
-        $this->assertSame($expectedFiles, $actualFiles);
+        $this->assertEqualsCanonicalizing($expectedFiles, $actualFiles);
 
         $expectedDumpedConfig = <<<'EOF'
 //
@@ -1294,12 +1299,12 @@ EOF;
 
         // Checks one of the dumped file from the PHAR to ensure the encoding of the extracted file is correct
         $this->assertSame(
-            get_contents('.box_dump/index.php'),
+            file_get_contents('.box_dump/index.php'),
             $indexContents
         );
     }
 
-    public function test_it_can_build_a_PHAR_file_in_quiet_mode(): void
+    public function test_it_can_build_a_phar_file_in_quiet_mode(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
@@ -1356,15 +1361,15 @@ EOF;
         $pharContents = file_get_contents('test.phar');
         $shebang = preg_quote($shebang, '/');
 
-        $this->assertRegExp("/$shebang/", $pharContents);
-        $this->assertRegExp('/custom banner/', $pharContents);
+        $this->assertMatchesRegularExpression("/$shebang/", $pharContents);
+        $this->assertMatchesRegularExpression('/custom banner/', $pharContents);
 
         $phar = new Phar('test.phar');
 
         $this->assertSame(['rand' => $rand], $phar->getMetadata());
     }
 
-    public function test_it_can_build_a_PHAR_file_using_the_PHAR_default_stub(): void
+    public function test_it_can_build_a_phar_file_using_the_phar_default_stub(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
@@ -1409,7 +1414,7 @@ EOF;
         );
     }
 
-    public function test_it_can_build_a_PHAR_file_using_a_custom_stub(): void
+    public function test_it_can_build_a_phar_file_using_a_custom_stub(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
@@ -1481,7 +1486,7 @@ PHP
         $this->assertSame($stub, $actualStub);
     }
 
-    public function test_it_can_build_a_PHAR_file_using_the_default_stub(): void
+    public function test_it_can_build_a_phar_file_using_the_default_stub(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
@@ -1514,7 +1519,7 @@ PHP
         );
     }
 
-    public function test_it_cannot_build_a_PHAR_using_unreadable_files(): void
+    public function test_it_cannot_build_a_phar_using_unreadable_files(): void
     {
         touch('index.php');
         touch('unreadable-file.php');
@@ -1540,14 +1545,14 @@ PHP
 
             $this->fail('Expected exception to be thrown.');
         } catch (InvalidArgumentException $exception) {
-            $this->assertRegExp(
-                '/^Path ".+?" was expected to be readable\.$/',
+            $this->assertMatchesRegularExpression(
+                '/^The path ".+?" is not readable\.$/',
                 $exception->getMessage()
             );
         }
     }
 
-    public function test_it_can_build_a_PHAR_overwriting_an_existing_one_in_verbose_mode(): void
+    public function test_it_can_build_a_phar_overwriting_an_existing_one_in_verbose_mode(): void
     {
         mirror(self::FIXTURES_DIR.'/dir002', $this->tmp);
 
@@ -1628,7 +1633,7 @@ OUTPUT;
 
         rename('run.php', 'index.php');
 
-        $this->assertFileNotExists($this->tmp.'/vendor/autoload.php');
+        $this->assertFileDoesNotExist($this->tmp.'/vendor/autoload.php');
 
         $this->commandTester->execute(
             ['command' => 'compile'],
@@ -1637,7 +1642,7 @@ OUTPUT;
 
         $output = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
-        $this->assertRegExp(
+        $this->assertMatchesRegularExpression(
             '/\? Dumping the Composer autoloader/',
             $output,
             'Expected the autoloader to be dumped'
@@ -1660,13 +1665,13 @@ OUTPUT;
         }
     }
 
-    public function test_it_can_build_a_PHAR_without_dumping_the_autoloader(): void
+    public function test_it_can_build_a_phar_without_dumping_the_autoloader(): void
     {
         mirror(self::FIXTURES_DIR.'/dir000', $this->tmp);
 
         rename('run.php', 'index.php');
 
-        $this->assertFileNotExists($this->tmp.'/vendor/autoload.php');
+        $this->assertFileDoesNotExist($this->tmp.'/vendor/autoload.php');
 
         dump_file(
             'box.json',
@@ -1684,7 +1689,7 @@ OUTPUT;
 
         $output = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
-        $this->assertRegExp(
+        $this->assertMatchesRegularExpression(
             '/\? Skipping dumping the Composer autoloader/',
             $output,
             'Did not expect the autoloader to be dumped'
@@ -1703,7 +1708,7 @@ OUTPUT;
         ];
 
         foreach ($composerFiles as $composerFile) {
-            $this->assertFileNotExists('phar://index.phar/'.$composerFile);
+            $this->assertFileDoesNotExist('phar://index.phar/'.$composerFile);
         }
     }
 
@@ -1713,7 +1718,7 @@ OUTPUT;
 
         rename('run.php', 'index.php');
 
-        $this->assertFileNotExists($this->tmp.'/vendor/autoload.php');
+        $this->assertFileDoesNotExist($this->tmp.'/vendor/autoload.php');
 
         $this->commandTester->execute(
             ['command' => 'compile'],
@@ -1722,7 +1727,7 @@ OUTPUT;
 
         $output = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
-        $this->assertRegExp(
+        $this->assertMatchesRegularExpression(
             '/\? Removing the Composer dump artefacts/',
             $output,
             'Expected the composer files to be removed'
@@ -1751,7 +1756,7 @@ OUTPUT;
         ];
 
         foreach ($removedComposerFiles as $composerFile) {
-            $this->assertFileNotExists('phar://index.phar/'.$composerFile);
+            $this->assertFileDoesNotExist('phar://index.phar/'.$composerFile);
         }
     }
 
@@ -1766,7 +1771,7 @@ OUTPUT;
             json_encode(['exclude-composer-files' => false])
         );
 
-        $this->assertFileNotExists($this->tmp.'/vendor/autoload.php');
+        $this->assertFileDoesNotExist($this->tmp.'/vendor/autoload.php');
 
         $this->commandTester->execute(
             ['command' => 'compile'],
@@ -1775,7 +1780,7 @@ OUTPUT;
 
         $output = $this->normalizeDisplay($this->commandTester->getDisplay(true));
 
-        $this->assertRegExp(
+        $this->assertMatchesRegularExpression(
             '/\? Keep the Composer dump artefacts/',
             $output,
             'Expected the composer files to be kept'
@@ -1810,7 +1815,7 @@ OUTPUT;
         }
     }
 
-    public function test_it_can_build_a_PHAR_with_a_custom_banner(): void
+    public function test_it_can_build_a_phar_with_a_custom_banner(): void
     {
         mirror(self::FIXTURES_DIR.'/dir003', $this->tmp);
 
@@ -1879,7 +1884,7 @@ OUTPUT;
         );
     }
 
-    public function test_it_can_build_a_PHAR_with_a_stub_file(): void
+    public function test_it_can_build_a_phar_with_a_stub_file(): void
     {
         mirror(self::FIXTURES_DIR.'/dir004', $this->tmp);
 
@@ -1944,7 +1949,7 @@ OUTPUT;
         );
     }
 
-    public function test_it_can_build_a_PHAR_with_the_default_stub_file(): void
+    public function test_it_can_build_a_phar_with_the_default_stub_file(): void
     {
         mirror(self::FIXTURES_DIR.'/dir005', $this->tmp);
 
@@ -2010,7 +2015,7 @@ OUTPUT;
         $this->assertSame($expected, $actual);
     }
 
-    public function test_it_can_build_a_PHAR_without_a_main_script(): void
+    public function test_it_can_build_a_phar_without_a_main_script(): void
     {
         mirror(self::FIXTURES_DIR.'/dir004', $this->tmp);
 
@@ -2086,7 +2091,7 @@ OUTPUT;
         );
     }
 
-    public function test_it_can_build_an_empty_PHAR(): void
+    public function test_it_can_build_an_empty_phar(): void
     {
         mirror(self::FIXTURES_DIR.'/dir004', $this->tmp);
 
@@ -2166,10 +2171,10 @@ OUTPUT;
 
         $actualFiles = $this->retrievePharFiles(new Phar('test.phar'));
 
-        $this->assertSame($expectedFiles, $actualFiles);
+        $this->assertEqualsCanonicalizing($expectedFiles, $actualFiles);
     }
 
-    public function test_it_can_build_a_PHAR_with_compressed_code(): void
+    public function test_it_can_build_a_phar_with_compressed_code(): void
     {
         mirror(self::FIXTURES_DIR.'/dir006', $this->tmp);
 
@@ -2247,7 +2252,7 @@ OUTPUT;
         );
     }
 
-    public function test_it_can_build_a_PHAR_in_a_non_existent_directory(): void
+    public function test_it_can_build_a_phar_in_a_non_existent_directory(): void
     {
         mirror(self::FIXTURES_DIR.'/dir007', $this->tmp);
 
@@ -2322,7 +2327,7 @@ OUTPUT;
     /**
      * @dataProvider provideAliasConfig
      */
-    public function test_it_configures_the_PHAR_alias(bool $stub): void
+    public function test_it_configures_the_phar_alias(bool $stub): void
     {
         mirror(self::FIXTURES_DIR.'/dir008', $this->tmp);
 
@@ -2367,11 +2372,11 @@ OUTPUT;
         if ($stub) {
             $this->assertSame($phar->getPath(), $phar->getAlias());
 
-            $this->assertNotRegExp(
+            $this->assertDoesNotMatchRegularExpression(
                 '/Phar::webPhar\(.*\);/',
                 $actualStub
             );
-            $this->assertRegExp(
+            $this->assertMatchesRegularExpression(
                 '/Phar::mapPhar\(\'alias-test\.phar\'\);/',
                 $actualStub
             );
@@ -2382,7 +2387,7 @@ OUTPUT;
 
             // No alias is found: I find it weird but well, that's the default stub so there is not much that can
             // be done here. Maybe there is a valid reason I'm not aware of.
-            $this->assertNotRegExp(
+            $this->assertDoesNotMatchRegularExpression(
                 '/alias-test\.phar/',
                 $actualStub
             );
@@ -2394,16 +2399,16 @@ OUTPUT;
 
         $actualFiles = $this->retrievePharFiles($phar);
 
-        $this->assertSame($expectedFiles, $actualFiles);
+        $this->assertEqualsCanonicalizing($expectedFiles, $actualFiles);
     }
 
-    public function test_it_can_build_a_PHAR_file_without_a_shebang_line(): void
+    public function test_it_can_build_a_phar_file_without_a_shebang_line(): void
     {
         mirror(self::FIXTURES_DIR.'/dir006', $this->tmp);
 
         $boxRawConfig = json_decode(file_get_contents('box.json'), true, 512, JSON_PRETTY_PRINT);
         $boxRawConfig['shebang'] = false;
-        dump_file('box.json', json_encode($boxRawConfig), JSON_PRETTY_PRINT);
+        dump_file('box.json', json_encode($boxRawConfig, JSON_PRETTY_PRINT));
 
         $this->commandTester->execute(
             ['command' => 'compile'],
@@ -2479,7 +2484,7 @@ OUTPUT;
         );
     }
 
-    public function test_it_can_build_a_PHAR_with_an_output_which_does_not_have_a_PHAR_extension(): void
+    public function test_it_can_build_a_phar_with_an_output_which_does_not_have_a_phar_extension(): void
     {
         mirror(self::FIXTURES_DIR.'/dir004', $this->tmp);
 
@@ -2557,7 +2562,7 @@ OUTPUT;
         );
     }
 
-    public function test_it_can_build_a_PHAR_ignoring_the_configuration(): void
+    public function test_it_can_build_a_phar_ignoring_the_configuration(): void
     {
         mirror(self::FIXTURES_DIR.'/dir009', $this->tmp);
 
@@ -2596,7 +2601,7 @@ OUTPUT;
         );
     }
 
-    public function test_it_can_build_a_PHAR_with_a_PHPScoper_config(): void
+    public function test_it_can_build_a_phar_with_a_php_scoper_config(): void
     {
         mirror(self::FIXTURES_DIR.'/dir010', $this->tmp);
 
@@ -2630,7 +2635,7 @@ OUTPUT;
         $this->assertStringStartsWith('_HumbugBox', $phpScoperNamespace);
     }
 
-    public function test_it_can_build_a_PHAR_with_a_PHPScoper_config_with_a_specific_prefix(): void
+    public function test_it_can_build_a_phar_with_a_php_scoper_config_with_a_specific_prefix(): void
     {
         mirror(self::FIXTURES_DIR.'/dir010', $this->tmp);
 
@@ -2666,7 +2671,7 @@ OUTPUT;
         $this->assertSame('Acme', $phpScoperNamespace);
     }
 
-    public function test_it_cannot_sign_a_PHAR_with_the_OpenSSL_algorithm_without_a_private_key(): void
+    public function test_it_cannot_sign_a_phar_with_the_openssl_algorithm_without_a_private_key(): void
     {
         mirror(self::FIXTURES_DIR.'/dir010', $this->tmp);
 
@@ -2845,7 +2850,7 @@ OUTPUT;
         $this->assertSame($expected, $actual, 'Expected logs to be identical');
     }
 
-    public function test_it_can_generate_a_PHAR_with_docker(): void
+    public function test_it_can_generate_a_phar_with_docker(): void
     {
         if (extension_loaded('xdebug')) {
             $this->markTestSkipped('Skipping this test since xdebug has an include wrapper causing this test to fail');
@@ -2865,6 +2870,7 @@ OUTPUT;
         );
 
         $version = get_box_version();
+        $expectedNumberOfFiles = 43;
 
         $expected = <<<OUTPUT
 
@@ -2905,7 +2911,7 @@ Box version 3.x-dev@151e40a
 No recommendation found.
 No warning found.
 
- // PHAR: 40 files (100B)
+ // PHAR: $expectedNumberOfFiles files (100B)
  // You can inspect the generated PHAR with the "info" command.
 
  // Memory usage: 5.00MB (peak: 10.00MB), time: 0.00s
@@ -2968,6 +2974,32 @@ OUTPUT;
             $display
         );
 
+        $display = str_replace(
+            'Xdebug',
+            'xdebug',
+            $display
+        );
+
+        $display = preg_replace(
+            '/\[debug\] Increased the maximum number of open file descriptors from \([^\)]+\) to \([^\)]+\)'.PHP_EOL.'/',
+            '',
+            $display
+        );
+
+        $display = str_replace(
+            '[debug] Restored the maximum number of open file descriptors'.PHP_EOL,
+            '',
+            $display
+        );
+
+        if (extension_loaded('xdebug')) {
+            $display = preg_replace(
+                '/'.PHP_EOL.'You are running composer with xdebug enabled. This has a major impact on runtime performance. See https:\/[^\s]+'.PHP_EOL.'/',
+                '',
+                $display
+            );
+        }
+
         return DisplayNormalizer::removeTrailingSpaces($display);
     }
 
